==> Botan-1.1.13.tgz: Botan-1.1.13/src/data_snk.cpp <==
/*************************************************
* DataSink Sink File                             *
* (C) 1999-2003 The Botan Project                *
*************************************************/

#include <botan/data_snk.h>
#include <fstream>

namespace Botan {

/*************************************************
* Write to a stream                              *
*************************************************/
void DataSink_Stream::write(const byte out[], u32bit length)
   {
   sink->write((char*)out, length);
   if(!sink->good())
      throw Stream_IO_Error("DataSink_Stream: Failure writing to " + filename);
   }

/*************************************************
* DataSink_Stream Constructor                    *
*************************************************/
DataSink_Stream::DataSink_Stream(std::ostream& stream) :
   filename("std::ostream")
   {
   sink = &stream;
   owns = false;
   }

/*************************************************
* DataSink_Stream Constructor                    *
*************************************************/
DataSink_Stream::DataSink_Stream(const std::string& file) :
   filename(file)
   {
   sink = new std::ofstream(filename.c_str());
   if(!sink->good())
      throw Stream_IO_Error("DataSink_Stream: Failure opening " + filename);
   owns = true;
   }

/*************************************************
* DataSink_Stream Destructor                     *
*************************************************/
DataSink_Stream::~DataSink_Stream()
   {
   if(owns)
      delete sink;
   sink = 0;
   }

}

==> Botan-1.3.3.tgz: Botan-1.3.3/src/data_snk.cpp <==
/*************************************************
* DataSink Sink File                             *
* (C) 1999-2003 The Botan Project                *
*************************************************/

#include <botan/data_snk.h>
#include <fstream>

namespace Botan {

/*************************************************
* Write to a stream                              *
*************************************************/
void DataSink_Stream::write(const byte out[], u32bit length)
   {
   sink->write((char*)out, length);
   if(!sink->good())
      throw Stream_IO_Error("DataSink_Stream: Failure writing to " + fsname);
   }

/*************************************************
* DataSink_Stream Constructor                    *
*************************************************/
DataSink_Stream::DataSink_Stream(std::ostream& stream) : fsname("std::ostream")
   {
   sink = &stream;
   owns = false;
   }

/*************************************************
* DataSink_Stream Constructor                    *
*************************************************/
DataSink_Stream::DataSink_Stream(const std::string& file) : fsname(file)
   {
   sink = new std::ofstream(fsname.c_str());
   if(!sink->good())
      throw Stream_IO_Error("DataSink_Stream: Failure opening " + fsname);
   owns = true;
   }

/*************************************************
* DataSink_Stream Destructor                     *
*************************************************/
DataSink_Stream::~DataSink_Stream()
   {
   if(owns)
      delete sink;
   sink = 0;
   }

}
